.. Last updated Thu Aug  9 15:33:27 BST 2012

Tests
=====

Designs
-------

.. automodule:: designs_tests
   :members:

Graphs
------

.. automodule:: graphs_tests
   :members:

Hall
----

.. automodule:: hall_tests
   :members:

Output
------

.. automodule:: output_tests
   :members:

Utils
-----

.. automodule:: utils_tests
   :members:

